From 7c1e078b2ab9c4f0cb3e6cca60bafcccd3410e5f Mon Sep 17 00:00:00 2001
From: Eric Wasylishen <ewasylishen@gmail.com>
Date: Mon, 1 Sep 2014 07:30:23 +0000
Subject: [PATCH] PF_VarString: raise buffer size to 1024. I checked all buffers
 that the resulting string could end up in, and they're all at least 1024
 bytes (even with an unmodified quake client).

PF_VarString is only called on the server, in:
- PF_error, PF_objerror, PF_dprint to print error / debugging messages
- PF_bprint, which calls SV_BroadcastPrintf which copies the string into a 1024-byte buffer, then sends that to clients in a svc_print message
- PF_sprint, which sends the string in a svc_print message using MSG_WriteString (without copying into an intermediate buffer)
- PF_centerprint, which sends the return value of PF_VarString in a svc_centerprint message (without copying into an intermediate buffer)

On the client:
- svc_print reads the payload string with MSG_ReadString (2048-byte buffer), then Con_Printf is called (4096-byte buffer)
- svc_centerprint uses MSG_ReadString then calls SCR_CenterPrint (1024-byte buffer)

I also checked the original quake source and the client-side buffers for MSG_ReadString, Con_Printf, and SCR_CenterPrint are all the same sizes as in QS.

Admittedly I want to support sock's ITS mod, but as far as I can see, it's a totally safe to increase this to 1024.

git-svn-id: svn://svn.code.sf.net/p/quakespasm/code/trunk/quakespasm@985 af15c1b1-3010-417e-b628-4374ebc0bcbd
---
 Quake/pr_cmds.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/Quake/pr_cmds.c b/Quake/pr_cmds.c
index c650b7a9..8eba5b95 100644
--- a/Quake/pr_cmds.c
+++ b/Quake/pr_cmds.c
@@ -49,7 +49,7 @@ static char *PR_GetTempString (void)
 static char *PF_VarString (int	first)
 {
 	int		i;
-	static char out[384];
+	static char out[1024];
 	size_t s;
 
 	out[0] = 0;
